<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN įjungta</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN išjungta</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock įjungtas</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock išjungtas</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Numerinė klaviatūra įjungta</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Numerinė klaviatūra išjungta</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad įjungtas</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad išjungtas</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Touchpad atidaryti/uždaryti</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn mygtukas atidaryti/uždaryti</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Lentos režimas įjungtas</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Lentos režimas išjungtas</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Balansuota energijos tvarka</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Energo užtikrinimas</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Greitas atnešimas</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Langų efektai įjungti</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Langų efektai išjungti</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Nepavyko įjungti langų efektų</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>